@@ -1,3 +1,4 @@
+import math
 import os
 import sys
 import pytest
@@ -11,8 +12,8 @@ import numpy as np
 import pandas as pd
 import time
 
-GB = 1024 * 1024 * 1024
-MB = 1024 * 1024
+GB = 1024. * 1024. * 1024.
+MB = 1024. * 1024.
 
 
 def pytest_addoption(parser):
@@ -72,23 +73,6 @@ def pytest_configure(config):
     config.addinivalue_line("markers", "source: mark test as a source function")
 
 
-# def pytest_collection_modifyitems(config, items):
-# """ This function makes pytest skip the source or destination tests, depending if the --source or --destination
-# flag is not present. """
-# if not config.getoption("--source"):
-#     # makes the test print the reason the test was skipped
-#     skip_source = pytest.mark.skip(reason="need --source option to run")
-#     for item in items:
-#         if "source" in item.keywords:
-#             item.add_marker(skip_source)
-#
-# if not config.getoption("--destination"):
-#     skip_destination = pytest.mark.skip(reason="need --destination option to run")
-#     for item in items:
-#         if "destination" in item.keywords:
-#             item.add_marker(skip_destination)
-
-
 @pytest.fixture(scope="session")
 def env(env_file):
     load_dotenv(env_file)
@@ -315,7 +299,7 @@ def generate_batch(batch_rows):
     return [to_dc_format(df), end - start]
 
 
-@pytest.fixture(scope="session", params=[1, 10, 100, 1000])
+@pytest.fixture(scope="session", params=[0.25, 0.5, 1.0, 10.0, 100.0, 1000.0])
 def num_gigs(request):
     return request.param
 
@@ -324,12 +308,12 @@ def num_gigs(request):
 def load_data(connector, generate_batch, good_object_id, mapping_object, _replace, num_gigs, batch_size, batch_rows):
     start = time.time()
     size = num_gigs
-    total_batches = (size * GB) / batch_size
     batch_number = 1
     rows_loaded = 0
     generate_data_time = 0
 
     batch = generate_batch
+    total_batches = math.ceil((size * GB) / sys.getsizeof(batch[0]))
     generate_data_time += batch[1]
     connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
 
@@ -342,22 +326,24 @@ def load_data(connector, generate_batch, good_object_id, mapping_object, _replac
         connector.load_data(batch[0], good_object_id, mapping_object, _replace, batch_number, total_batches)
 
     end = time.time()
-    print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}.\nTotal size uploaded: {size * GB}")
+    print(f"Loaded {rows_loaded} rows out of {total_batches * batch_rows}."
+          f"\nTotal size uploaded: {size * GB} bytes, which is {size} GB.")
 
     elapsed_time = end - start - generate_data_time
-    hours = elapsed_time / (60 * 60)
-    minutes = (elapsed_time % (60 * 60)) / 60
-    seconds = (elapsed_time % (60 * 60)) % 60
+    hours = elapsed_time / (60. * 60.)
+    minutes = (elapsed_time % (60. * 60.)) / 60.
+    seconds = (elapsed_time % (60. * 60.)) % 60.
     formatted_time = f"{hours} Hours {minutes} Minutes and {seconds} seconds"
 
-    print(f"Time elapsed to load {num_gigs} GB: " + formatted_time)
+    print(f"Time elapsed to load {num_gigs} GB: {formatted_time}.")
     print(f"\t({end - start} total seconds - {generate_data_time} seconds to generate data)")
-    assert elapsed_time < 10 * 60
+    assert elapsed_time < (10. * 60.)
     return True
 
 
 @pytest.fixture(scope="session")
 def mapping_object():
+    # FIXME: these data types might be different for different connectors but its fine for right now
     return [
         {'source_field_id': "First", 'destination_field_id': "newfirst", 'datatype': "varchar(128)", 'size': None},
         {'source_field_id': "Last", 'destination_field_id': "newlast", 'datatype': "varchar(256)", 'size': None},
